from setuptools_scm import get_version


# These are conventions that would be accessible like this:
# print(pp_project_hmv.__author__)
__author__ = "Hernando M. Vergara"
__version__ = get_version()
__license__ = "whatever"

print("I am being initiated, thank you... hehehe")

# here I could import stuff from the inner modules so that
# they are importable directly from pp_project_hmv
# let's say 'stuff' is inside module A, I can add this here
# from .moduleA import stuff
# then I can do from within another repo that uses this:
# from pp_project_hmv import stuff



from typing import Union


def add_numbers(
    a: Union[int, float], b: Union[int, float]
) -> Union[int, float]:
    return a + b


def subtract_numbers(a, b):
    return a - b


def multiply_numbers(a, b):
    return a * b



from pp_project_hmv import maths


def test_add_numbers():
    assert maths.add_numbers(1, 3) == 4, "adding 1 and 3 failed"
    assert maths.add_numbers(10, 100.1) == 110.1, "adding floats failed"
    # assert maths.add_numbers(1, 5) == 110.1, 'adding 1 and 5 failed'
